@@ -137,10 +137,11 @@ class ToggleRepeatButton(discord.ui.Button):
         if not player:
             return await interaction.response.send_message(
                 embed=await self.cog.lavalink.construct_embed(
-                    description="Not connected to a voice channel.", messageable=interaction
+                    description=_("Not connected to a voice channel."), messageable=interaction
                 ),
                 ephemeral=True,
             )
+        await player.config.update()
         repeat_queue = bool(player.config.repeat_current)
         await self.cog.command_repeat.callback(self.cog, interaction, queue=repeat_queue)
         await self.view.prepare()
@@ -148,6 +149,37 @@ class ToggleRepeatButton(discord.ui.Button):
         await (await interaction.original_message()).edit(view=self.view, **kwargs)
 
 
+class QueueHistoryButton(discord.ui.Button):
+    def __init__(self, cog: CogT, style: discord.ButtonStyle, row: int = None):
+        super().__init__(
+            style=style,
+            emoji=emojis.PLAYLIST,
+            row=row,
+        )
+        self.cog = cog
+
+    async def callback(self, interaction: InteractionT):
+        from pylavcogs_shared.ui.menus.queue import QueueMenu
+        from pylavcogs_shared.ui.sources.queue import QueueSource
+
+        player = self.cog.lavalink.get_player(interaction.guild)
+        if not player:
+            return await interaction.response.send_message(
+                embed=await self.cog.lavalink.construct_embed(
+                    description=_("Not connected to a voice channel."), messageable=interaction
+                ),
+                ephemeral=True,
+            )
+
+        await QueueMenu(
+            cog=self.cog,
+            bot=self.cog.bot,
+            source=QueueSource(guild_id=interaction.guild.id, cog=self.cog, history=True),
+            original_author=interaction.user,
+            history=True,
+        ).start(ctx=interaction)
+
+
 class ToggleRepeatQueueButton(discord.ui.Button):
     def __init__(self, cog: CogT, style: discord.ButtonStyle, row: int = None):
         super().__init__(
@@ -162,10 +194,11 @@ class ToggleRepeatQueueButton(discord.ui.Button):
         if not player:
             return await interaction.response.send_message(
                 embed=await self.cog.lavalink.construct_embed(
-                    description="Not connected to a voice channel.", messageable=interaction
+                    description=_("Not connected to a voice channel."), messageable=interaction
                 ),
                 ephemeral=True,
             )
+        await player.config.update()
         repeat_queue = bool(player.config.repeat_current)
         await self.cog.command_repeat.callback(self.cog, interaction, queue=repeat_queue)
         await self.view.prepare()
@@ -204,6 +237,36 @@ class DisconnectButton(discord.ui.Button):
         await self.view.on_timeout()
 
 
+class EmptyQueueButton(discord.ui.Button):
+    def __init__(self, cog: CogT, style: discord.ButtonStyle, row: int = None):
+        super().__init__(
+            style=style,
+            emoji=emojis.TRASH,
+            row=row,
+        )
+        self.cog = cog
+
+    async def callback(self, interaction: InteractionT):
+        player = self.cog.lavalink.get_player(interaction.guild)
+        if not player.queue.size():
+            return await interaction.response.send_message(
+                embed=await self.cog.lavalink.construct_embed(
+                    description=_("There's nothing in the Queue."), messageable=interaction
+                ),
+                ephemeral=True,
+            )
+        player.queue.clear()
+        await interaction.response.send_message(
+            embed=await self.cog.lavalink.construct_embed(
+                description=_("Removed tracks from the queue."), messageable=interaction
+            ),
+            ephemeral=True,
+        )
+        await self.view.prepare()
+        kwargs = await self.view.get_page(self.view.current_page)
+        await (await interaction.original_message()).edit(view=self.view, **kwargs)
+
+
 class EnqueueButton(discord.ui.Button):
     def __init__(
         self,
